# mypy-boto3-fis

[![PyPI - mypy-boto3-fis](https://img.shields.io/pypi/v/mypy-boto3-fis.svg?color=blue)](https://pypi.org/project/mypy-boto3-fis)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-fis.svg?color=blue)](https://pypi.org/project/mypy-boto3-fis)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-fis?color=blue)](https://pypistats.org/packages/mypy-boto3-fis)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.FIS 1.17.63](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/fis.html#FIS)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-fis docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_fis/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-fis](#mypy-boto3-fis)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `FIS` service.

```bash
python -m pip install boto3-stubs[fis]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[fis]` in your environment:
  `python -m pip install 'boto3-stubs[fis]'`

Both type checking and auto-complete should work for `FIS` service. No explicit
type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[fis]` in your environment:
  `python -m pip install 'boto3-stubs[fis]'`

Both type checking and auto-complete should work for `FIS` service. No explicit
type annotations required, write your `boto3` code as usual. Auto-complete can
be slow on big projects or if you have a lot of installed `boto3-stubs`
submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[fis]` in your environment:
  `python -m pip install 'boto3-stubs[fis]'`
- Run `mypy` as usual

Type checking should work for `FIS` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[fis]` in your environment:
  `python -m pip install 'boto3-stubs[fis]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `FIS` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`FISClient` provides annotations for `boto3.client("fis")`.

```python
import boto3

from mypy_boto3_fis import FISClient

client: FISClient = boto3.client("fis")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: FISClient = session.client("fis")
```

### Literals

`mypy_boto3_fis.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_fis.literals import (
    ExperimentActionStatus,
    ExperimentStatus,
)

def check_value(value: ExperimentActionStatus) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_fis.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_fis.type_defs import (
    ActionParameterTypeDef,
    ActionSummaryTypeDef,
    ActionTargetTypeDef,
    ActionTypeDef,
    CreateExperimentTemplateActionInputTypeDef,
    CreateExperimentTemplateResponseTypeDef,
    CreateExperimentTemplateStopConditionInputTypeDef,
    CreateExperimentTemplateTargetInputTypeDef,
    DeleteExperimentTemplateResponseTypeDef,
    ExperimentActionStateTypeDef,
    ExperimentActionTypeDef,
    ExperimentStateTypeDef,
    ExperimentStopConditionTypeDef,
    ExperimentSummaryTypeDef,
    ExperimentTargetFilterTypeDef,
    ExperimentTargetTypeDef,
    ExperimentTemplateActionTypeDef,
    ExperimentTemplateStopConditionTypeDef,
    ExperimentTemplateSummaryTypeDef,
    ExperimentTemplateTargetFilterTypeDef,
    ExperimentTemplateTargetInputFilterTypeDef,
    ExperimentTemplateTargetTypeDef,
    ExperimentTemplateTypeDef,
    ExperimentTypeDef,
    GetActionResponseTypeDef,
    GetExperimentResponseTypeDef,
    GetExperimentTemplateResponseTypeDef,
    ListActionsResponseTypeDef,
    ListExperimentTemplatesResponseTypeDef,
    ListExperimentsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    StartExperimentResponseTypeDef,
    StopExperimentResponseTypeDef,
    UpdateExperimentTemplateActionInputItemTypeDef,
    UpdateExperimentTemplateResponseTypeDef,
    UpdateExperimentTemplateStopConditionInputTypeDef,
    UpdateExperimentTemplateTargetInputTypeDef,
)

def get_structure() -> ActionParameterTypeDef:
    return {
      ...
    }
```
